@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.096'; 
+our $VERSION = '1.0961'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -705,7 +705,7 @@ sub set_listing_defaults {
     	$query->{after}  = $param{after}  if $param{after};
 	$query->{only}   = $param{only}   if $param{only};
 	$query->{count}  = $param{count}  if $param{count};
-	$query->{show}	 = 'all' 	  if $param{show};
+	$query->{show}	 = 'all' 	  if $param{show} or $param{show_all};
 	$query->{sr_detail} = 'true' 	  if $param{sr_detail};
    	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
 	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
