@@ -11,9 +11,10 @@ use fields qw/link_flair_text media url link_flair_css_class num_reports
               created_utc banned_by subreddit title author_flair_text is_self
               author media_embed author_flair_css_class selftext domain
               num_comments clicked saved thumbnail subreddit_id approved_by
-              selftext_html created hidden over_18 permalink/;
+              selftext_html created hidden over_18 permalink
+		user_reports mod_reports/;
 
-use constant type	=> "t3";
+use constant type => "t3";
 
 sub reply {
     my ($self, $text) = @_;
