@@ -7,6 +7,7 @@ use Carp;
 use LWP::UserAgent qw//;
 use HTTP::Request  qw//;
 use URI::Encode    qw/uri_encode/;
+use URI::Escape    qw/uri_escape/; # next update, also line 122
 
 require Reddit::Client;
 
@@ -118,7 +119,8 @@ sub token_request {
 	my $req = HTTP::Request->new(POST => $url);
 	$req->header('content-type' => 'application/x-www-form-urlencoded');
 
-	my $postdata = "grant_type=password&username=$username&password=$password";
+	#my $postdata = "grant_type=password&username=$username&password=$password";
+	my $postdata = "grant_type=password&username=$username&password=" . uri_escape($password);
 	$req->content($postdata);
 
     	my $res = $ua->request($req);
